@@ -41,6 +41,8 @@ using Rcpp::NumericMatrix;
  */
 
 double pdf_gev(double x, double mu, double sigma, double xi) {
+  if (ISNAN(x) || ISNAN(mu) || ISNAN(sigma) || ISNAN(xi))
+    return NA_REAL;
   if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -57,6 +59,8 @@ double pdf_gev(double x, double mu, double sigma, double xi) {
 }
 
 double cdf_gev(double x, double mu, double sigma, double xi) {
+  if (ISNAN(x) || ISNAN(mu) || ISNAN(sigma) || ISNAN(xi))
+    return NA_REAL;
   if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -73,6 +77,8 @@ double cdf_gev(double x, double mu, double sigma, double xi) {
 }
 
 double invcdf_gev(double p, double mu, double sigma, double xi) {
+  if (ISNAN(p) || ISNAN(mu) || ISNAN(sigma) || ISNAN(xi))
+    return NA_REAL;
   if (sigma <= 0.0 || p < 0.0 || p > 1.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
