@@ -34,6 +34,8 @@ using Rcpp::NumericMatrix;
 */
 
 double pdf_power(double x, double alpha, double beta) {
+  if (ISNAN(x) || ISNAN(alpha) || ISNAN(beta))
+    return NA_REAL;
   if (x < 0.0)
     return 0.0;
   if (x > 0.0 && x < alpha) {
@@ -44,6 +46,8 @@ double pdf_power(double x, double alpha, double beta) {
 }
 
 double cdf_power(double x, double alpha, double beta) {
+  if (ISNAN(x) || ISNAN(alpha) || ISNAN(beta))
+    return NA_REAL;
   if (x < 0.0)
     return 0.0;
   if (x > 0.0 && x < alpha) {
@@ -56,6 +60,8 @@ double cdf_power(double x, double alpha, double beta) {
 }
 
 double invcdf_power(double p, double alpha, double beta) {
+  if (ISNAN(p) || ISNAN(alpha) || ISNAN(beta))
+    return NA_REAL;
   if (p < 0.0 || p > 1.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -64,6 +70,8 @@ double invcdf_power(double p, double alpha, double beta) {
 }
 
 double logpdf_power(double x, double alpha, double beta) {
+  if (ISNAN(x) || ISNAN(alpha) || ISNAN(beta))
+    return NA_REAL;
   if (x < 0.0)
     return -INFINITY;
   if (x > 0.0 && x < alpha) {
@@ -74,6 +82,8 @@ double logpdf_power(double x, double alpha, double beta) {
 }
 
 double logcdf_power(double x, double alpha, double beta) {
+  if (ISNAN(x) || ISNAN(alpha) || ISNAN(beta))
+    return NA_REAL;
   if (x < 0.0)
     return -INFINITY;
   if (x > 0.0 && x < alpha) {
