@@ -33,6 +33,8 @@ using Rcpp::NumericMatrix;
  */
 
 double pdf_rayleigh(double x, double sigma) {
+  if (ISNAN(x) || ISNAN(sigma))
+    return NA_REAL;
   if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -43,6 +45,8 @@ double pdf_rayleigh(double x, double sigma) {
 }
 
 double cdf_rayleigh(double x, double sigma) {
+  if (ISNAN(x) || ISNAN(sigma))
+    return NA_REAL;
   if (sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -56,6 +60,8 @@ double cdf_rayleigh(double x, double sigma) {
 }
 
 double invcdf_rayleigh(double p, double sigma) {
+  if (ISNAN(p) || ISNAN(sigma))
+    return NA_REAL;
   if (p < 0.0 || p > 1.0 || sigma <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
