@@ -31,6 +31,8 @@ using Rcpp::NumericMatrix;
  */
 
 double pdf_wald(double x, double mu, double lambda) {
+  if (ISNAN(x) || ISNAN(mu) || ISNAN(lambda))
+    return NA_REAL;
   if (mu <= 0.0 || lambda <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -42,6 +44,8 @@ double pdf_wald(double x, double mu, double lambda) {
 }
 
 double cdf_wald(double x, double mu, double lambda) {
+  if (ISNAN(x) || ISNAN(mu) || ISNAN(lambda))
+    return NA_REAL;
   if (mu <= 0.0 || lambda <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
@@ -56,6 +60,8 @@ double cdf_wald(double x, double mu, double lambda) {
 }
 
 double rng_wald(double mu, double lambda) {
+  if (ISNAN(mu) || ISNAN(lambda))
+    return NA_REAL;
   if (mu <= 0.0 || lambda <= 0.0) {
     Rcpp::warning("NaNs produced");
     return NAN;
